API 🔌
========================
This is where the api wrappers and endpoints are held.

.. toctree::
   :maxdepth: 1



NovaAPI Reference
---------------------------
.. automodule:: novauniverse.api
   :members:
   :undoc-members:
   :show-inheritance:


NovaCDN Reference
---------------------------
.. automodule:: novauniverse.api.cdn
   :members:
   :undoc-members:
   :show-inheritance:


Endpoints Reference
---------------------------------
.. automodule:: novauniverse.api.endpoints
   :members:
   :undoc-members:
   :show-inheritance:


Errors Reference
------------------------------
.. automodule:: novauniverse.api.errors
   :members:
   :undoc-members:
   :show-inheritance: